@@ -195,6 +195,9 @@ class Request:
 
         granule_id: The CMR Granule ID for the granule which should be retrieved
 
+        granule_name: The granule ur or provider id for the granule(s) to be retrieved
+          wildcards * (multi character match) and ? (single character match) are supported
+
         width: number of columns to return in the output coverage
 
         height: number of rows to return in the output coverage
@@ -208,6 +211,15 @@ class Request:
         skip_preview: Whether Harmony should skip auto-pausing and generating a preview for
           large jobs
 
+        ignore_errors: if "true", continue processing a request to completion
+          even if some items fail
+
+        destination_url: Destination URL specified by the client
+          (only S3 is supported, e.g. s3://my-bucket-name/mypath)
+
+        grid: The name of the output grid to use for regridding requests. The name must
+          match the UMM grid name in the CMR.
+
     Returns:
         A Harmony Request instance
     """
@@ -219,8 +231,10 @@ class Request:
                  temporal: Mapping[str, datetime] = None,
                  dimensions: List[Dimension] = None,
                  crs: str = None,
+                 destination_url: str = None,
                  format: str = None,
                  granule_id: List[str] = None,
+                 granule_name: List[str] = None,
                  height: int = None,
                  interpolation: str = None,
                  max_results: int = None,
@@ -230,7 +244,9 @@ class Request:
                  variables: List[str] = ['all'],
                  width: int = None,
                  concatenate: bool = None,
-                 skip_preview: bool = None):
+                 skip_preview: bool = None,
+                 ignore_errors: bool = None,
+                 grid: str = None):
         """Creates a new Request instance from all specified criteria.'
         """
         self.collection = collection
@@ -238,8 +254,10 @@ class Request:
         self.temporal = temporal
         self.dimensions = dimensions
         self.crs = crs
+        self.destination_url = destination_url
         self.format = format
         self.granule_id = granule_id
+        self.granule_name = granule_name
         self.height = height
         self.interpolation = interpolation
         self.max_results = max_results
@@ -250,20 +268,26 @@ class Request:
         self.width = width
         self.concatenate = concatenate
         self.skip_preview = skip_preview
+        self.ignore_errors = ignore_errors
+        self.grid = grid
 
         self.variable_name_to_query_param = {
             'crs': 'outputcrs',
+            'destination_url': 'destinationUrl',
             'interpolation': 'interpolation',
             'scale_extent': 'scaleExtent',
             'scale_size': 'scaleSize',
             'shape': 'shapefile',
             'granule_id': 'granuleId',
+            'granule_name': 'granuleName',
             'width': 'width',
             'height': 'height',
             'format': 'format',
             'max_results': 'maxResults',
             'concatenate': 'concatenate',
             'skip_preview': 'skipPreview',
+            'ignore_errors': 'ignoreErrors',
+            'grid': 'grid',
         }
 
         self.spatial_validations = [
@@ -295,6 +319,10 @@ class Request:
             (lambda dim: dim.min is None or dim.max is None or dim.min <= dim.max,
              ('Dimension minimum value must be less than or equal to the maximum value'))
         ]
+        self.parameter_validations = [  # for simple, one-off validations
+            (True if self.destination_url is None else self.destination_url.startswith('s3://'),
+             ('Destination URL must be an S3 location'))
+        ]
 
     def parameter_values(self) -> List[Tuple[str, Any]]:
         """Returns tuples of each query parameter that has been set and its value."""
@@ -325,6 +353,7 @@ class Request:
         spatial_msgs = []
         temporal_msgs = []
         dimension_msgs = []
+        parameter_msgs = [m for v, m in self.parameter_validations if not v]
         shape_msgs = self._shape_error_messages(self.shape)
         if self.spatial:
             spatial_msgs = [m for v, m in self.spatial_validations if not v(self.spatial)]
@@ -336,7 +365,7 @@ class Request:
                 if msgs:
                     dimension_msgs += msgs
 
-        return spatial_msgs + temporal_msgs + shape_msgs + dimension_msgs
+        return spatial_msgs + temporal_msgs + shape_msgs + dimension_msgs + parameter_msgs
 
 
 class LinkType(Enum):
@@ -367,6 +396,10 @@ class Client:
 
         >>> client = Client(auth=('rfeynman', 'quantumf1eld5'))
 
+    You can also create a Harmony client using user's EDL token::
+
+        >>> client = Client(token='myEDLTokenValue')
+
     By default, the Client will validate the provided credentials immediately. This can be
     disabled by passing ``should_validate_auth=False``.
     """
@@ -377,6 +410,7 @@ class Client:
         auth: Optional[Tuple[str, str]] = None,
         should_validate_auth: bool = True,
         env: Environment = Environment.PROD,
+        token: str = None,
         # How often to poll Harmony for updated information during job processing
         check_interval: float = 3.0  # in seconds
     ):
@@ -389,6 +423,7 @@ class Client:
         self.config = Config(env)
         self.session = None
         self.auth = auth
+        self.token = token
         self.check_interval = check_interval
 
         num_workers = int(self.config.NUM_REQUESTS_WORKERS)
@@ -400,7 +435,10 @@ class Client:
     def _session(self):
         """Creates (if needed) and returns the Client's requests Session."""
         if self.session is None:
-            self.session = create_session(self.config, self.auth)
+            if self.token:
+                self.session = create_session(self.config, token=self.token)
+            else:
+                self.session = create_session(self.config, auth=self.auth)
         return self.session
 
     def _submit_url(self, request: Request) -> str:
@@ -711,8 +749,8 @@ class Client:
             status_subset = {k: v for k, v in response.json().items() if k in fields}
             created_at_dt = dateutil.parser.parse(status_subset['createdAt'])
             updated_at_dt = dateutil.parser.parse(status_subset['updatedAt'])
-            data_expiration_dt = dateutil.parser.parse(status_subset['dataExpiration'])
-            return {
+
+            status_json = {
                 'status': status_subset['status'],
                 'message': status_subset['message']
                 .replace(' The job may be resumed using the provided link.', ''),
@@ -721,12 +759,16 @@ class Client:
                 'updated_at': updated_at_dt,
                 'created_at_local': created_at_dt.replace(microsecond=0).astimezone().isoformat(),
                 'updated_at_local': updated_at_dt.replace(microsecond=0).astimezone().isoformat(),
-                'data_expiration': data_expiration_dt,
-                'data_expiration_local': data_expiration_dt.
-                replace(microsecond=0).astimezone().isoformat(),
                 'request': status_subset['request'],
                 'num_input_granules': int(status_subset['numInputGranules']),
             }
+            if 'dataExpiration' in status_subset:
+                data_expiration_dt = dateutil.parser.parse(status_subset['dataExpiration'])
+                data_expiration_local = data_expiration_dt.replace(
+                    microsecond=0).astimezone().isoformat()
+                status_json['data_expiration'] = data_expiration_dt
+                status_json['data_expiration_local'] = data_expiration_local
+            return status_json
         else:
             self._handle_error_response(response)
 
@@ -806,6 +848,7 @@ class Client:
         """
         # How often to refresh the screen for progress updates and animating spinners.
         ui_update_interval = 0.33  # in seconds
+        running_w_errors_logged = False
 
         intervals = round(self.check_interval / ui_update_interval)
         if show_progress:
@@ -821,6 +864,10 @@ class Client:
                     if status == 'paused':
                         print('\nJob has been paused. Call `resume()` to resume.', file=sys.stderr)
                         break
+                    if (not running_w_errors_logged and status == 'running_with_errors'):
+                        print('\nJob is running with errors.', file=sys.stderr)
+                        running_w_errors_logged = True
+
                     # This gets around an issue with progressbar. If we update() with 0, the
                     # output shows up as "N/A". If we update with, e.g. 0.1, it rounds down or
                     # truncates to 0 but, importantly, actually displays that.
@@ -845,6 +892,9 @@ class Client:
                 if status == 'paused':
                     print('Job has been paused. Call `resume()` to resume.', file=sys.stderr)
                     break
+                if (not running_w_errors_logged and status == 'running_with_errors'):
+                    print('\nJob is running with errors.', file=sys.stderr)
+                    running_w_errors_logged = True
                 time.sleep(self.check_interval)
 
     def result_json(self,
